// Copyright Ryan Schmidt 2011.
// Distributed under the Boost Software License, Version 1.0.
// (See copy at http://www.boost.org/LICENSE_1_0.txt)


#ifndef __MM_SHAPEWAYS_IO_H__
#define __MM_SHAPEWAYS_IO_H__

#include <QtCore/qglobal.h>
#include <qtsoap.h>



class ShapewaysAPI : public QObject
{
    Q_OBJECT
public:
    ShapewaysAPI();
    ~ShapewaysAPI();

    void SetCredentials( const QString & username, const QString & password );

    void Login();
    void GetPrinters();


    enum ModelType {
        VRML, STL, X3D, X3DB, X3DV, DAE, ZIP
    };
    struct ModelInfo {
        QString title;
        QString description;
        QString tags;
        bool bHasColor;
        bool bOrderable;
        ModelType eModelType;
    };

    bool SubmitModel( const QString & filename, ModelInfo info );

    QString GetLastError() { return m_lastErrorMessage; }

private slots:
    void loginResponse(const QtSoapMessage &);
    void getPrintersResponse(const QtSoapMessage &);
    void submitModelResponse(const QtSoapMessage &);

signals:
    void loginReturned( bool );
    void submitModelReturned( bool );

protected:
    QtSoapHttpTransport m_http;

    QString m_host;
    QString m_apiURI;
    QString m_apiPath;

    QString m_username;
    QString m_password;
    QString m_applicationID;

    QString m_sessionID;

    bool m_bDebugPrint;
    QString m_lastErrorMessage;

};





#endif // __MM_SHAPEWAYS_IO_H__
